@@ -423,8 +423,9 @@ def GatherTrainingData(dictGeneral:dict,kmer:int,fragmentSize:int,outputPath:str
                         trainingSignature=[]
                         listepos= [0]
                         pos=0
+                        nbOfSamples=0
                         
-                        while pos<len(sequence):
+                        while pos<len(sequence) and nbOfSamples<=50:
 
                                 
                                 #Cuts sequence fragment
@@ -446,6 +447,7 @@ def GatherTrainingData(dictGeneral:dict,kmer:int,fragmentSize:int,outputPath:str
                                         normalizedSignature=fragmentSignature/np.sum(fragmentSignature.values)
                                         #We convert the signature to a list and put in inside trainingSignature
                                         trainingSignature.append(normalizedSignature.values[0])
+                                        nbOfSamples+=1
 
 
                                 if pos+fragmentSize>len(sequence):
@@ -478,8 +480,9 @@ def GatherTrainingData(dictGeneral:dict,kmer:int,fragmentSize:int,outputPath:str
                                 trainingSignature=[]
                                 listepos= [0]
                                 pos=0
+                                nbOfSamples=0
                                 
-                                while pos<len(sequence):
+                                while pos<len(sequence) and nbOfSamples<=50:
 
                                         
                                         #Cuts sequence fragment
@@ -501,6 +504,7 @@ def GatherTrainingData(dictGeneral:dict,kmer:int,fragmentSize:int,outputPath:str
                                                 normalizedSignature=fragmentSignature/np.sum(fragmentSignature.values)
                                                 #We convert the signature to a list and put in inside trainingSignature
                                                 trainingSignature.append(normalizedSignature.values[0])
+                                                nbOfSamples+=1
 
 
                                         if pos+fragmentSize>len(sequence):
@@ -518,7 +522,9 @@ def GatherTrainingData(dictGeneral:dict,kmer:int,fragmentSize:int,outputPath:str
                                 
                                 print("Number of Samples Gathered:", len(trainingSignature))
                                 print("Size of file:", sys.getsizeof(trainingSignature))
-                                np.savetxt(outputPath+'/'+phylum+'_'+organism+'.csv',trainingSignature,delimiter=",")
+                                print(organism)
+                                print(organism.replace("/","-"))
+                                np.savetxt(outputPath+'/'+phylum+'_'+organism.replace("/","-")+'.csv',trainingSignature,delimiter=",")
 
         return None
 
